@@ -32,8 +32,12 @@
 
 #include <string.h>      // for memcmp() and size_t
 #include <assert.h>
+#if 1
 #include <stdint.h>       // one place @ac_cv_unit64@ might live
+#endif
+#if 1
 #include <inttypes.h>     // another place @ac_cv_unit64@ might live
+#endif
 #include <sys/types.h>    // final place @ac_cv_unit64@ might live
 #include <tr1/unordered_map>
 #include <string>
@@ -150,7 +154,7 @@ class  TemplateString {
  public:
   TemplateString(const char* s)
       : ptr_(s ? s : ""), length_(strlen(ptr_)),
-        is_immutable_(InTextSegment(s)), id_(kIllegalTemplateId) {
+        is_immutable_(InTextSegment(ptr_)), id_(kIllegalTemplateId) {
   }
   TemplateString(const std::string& s)
       : ptr_(s.data()), length_(s.size()),
@@ -179,6 +183,10 @@ class  TemplateString {
   // Only TemplateDictionaries and template expansion code can read these.
   friend class OldTemplateDictionary;
   friend class TemplateDictionary;
+  friend class TemplateDictionaryPeer;           // TDP::GetSectionValue()
+  friend class Template;                         // for StringToTemplate()
+  friend class VariableTemplateNode;             // VTN::Expand()
+  friend class TemplateCache;                    // for GetGlobalId
   friend class StaticTemplateStringInitializer;  // for AddToGlo...
   friend struct TemplateStringHasher;            // for GetGlobalId
   friend class ::TemplateStringTest;
@@ -217,6 +225,11 @@ class  TemplateString {
   // Adds this TemplateString to the map from global-id to name.
   void AddToGlobalIdToNameMap();
 
+  // Use sparingly. Converting to a string loses information about the
+  // id of the template string, making operations require extra hash
+  // computations.
+  std::string ToString() const { return std::string(ptr_, length_); }
+
   // Does the reverse map from TemplateId to TemplateString contents.
   // Returns a TemplateString(kStsEmpty) if id isn't found.  Note that
   // the TemplateString returned is not necessarily NUL terminated.
